@@ -1,40 +1,41 @@
 package Pod::Weaver::Role::DumpPerinciCmdLineScript;
 
-our $DATE = '2014-12-26'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-07-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose::Role;
 
+use File::Slurper qw(write_binary);
 use Perinci::CmdLine::Dump;
 
 sub dump_perinci_cmdline_script {
     my ($self, $input) = @_;
 
-    my $filename = $input->{filename};
-
     # find file object
     my $file;
     for (@{ $input->{zilla}->files }) {
-        if ($_->name eq $filename) {
+        if ($_->name eq $input->{filename}) {
             $file = $_;
             last;
         }
     }
-    die "Can't find file object for $filename" unless $file;
+    die "Can't find file object for $input->{filename}" unless $file;
 
-    # if file object is not a real file on the filesystem, put it in a temporary
-    # file first so Perinci::CmdLine::Dump can see it.
-    unless ($file->isa("Dist::Zilla::File::OnDisk")) {
+    # because we need an actual file for Perinci::CmdLine::Dump, we'll dump the
+    # content of the file object to a temp file first. this includes DZF:OnDisk
+    # object too, because the content and the name might not match actual file
+    # on the filesystem anymore (e.g. see DZP:AddFile::FromFS where the file
+    # object has its name() changed).
+    my $tempname;
+    {
         require File::Temp;
-        my ($fh, $tempname) = File::Temp::tempfile();
-        print $fh $file->content;
-        close $fh;
-        $filename = $tempname;
+        (undef, $tempname) = File::Temp::tempfile();
+        write_binary($tempname, $file->content);
     }
 
     Perinci::CmdLine::Dump::dump_perinci_cmdline_script(
-        filename => $filename,
+        filename => $tempname,
         libs => ['lib'],
     );
 }
@@ -55,12 +56,16 @@ Pod::Weaver::Role::DumpPerinciCmdLineScript - Role to dump Perinci::CmdLine scri
 
 =head1 VERSION
 
-This document describes version 0.02 of Pod::Weaver::Role::DumpPerinciCmdLineScript (from Perl distribution Pod-Weaver-Role-DumpPerinciCmdLineScript), released on 2014-12-26.
+This document describes version 0.03 of Pod::Weaver::Role::DumpPerinciCmdLineScript (from Perl distribution Pod-Weaver-Role-DumpPerinciCmdLineScript), released on 2015-07-07.
 
 =head1 METHODS
 
 =head2 $obj->dump_perinci_cmdline_script($input)
 
+=head1 SEE ALSO
+
+L<Dist::Zilla::Role::DumpPerinciCmdLineScript>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Role-DumpPerinciCmdLineScript>.
@@ -83,7 +88,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
